package model

import model2 "gas-cylinder-api/common/model"

var (
	GasCylinderAllotStateAllot         = 1 // 调拨中
	GasCylinderAllotStateFinish        = 2 // 已完成
	GasCylinderAllotStateCancel        = 3 // 已取消
	GasCylinderAllotStateTimeoutCancel = 4 // 超时取消

	GasCylinderAllotStateMap = map[int]string{
		GasCylinderAllotStateAllot:         "已下单",
		GasCylinderAllotStateFinish:        "已完成",
		GasCylinderAllotStateCancel:        "已取消",
		GasCylinderAllotStateTimeoutCancel: "已超时取消",
	}
)

// 气瓶调拨
type GasCylinderAllot struct {
	model2.Model
	OptType             string            `json:"optType" gorm:"size:48"`               // 气瓶流转步骤
	AllotUserId         int               `json:"allotUserId" gorm:"size:48;"`          // 调拨者用户id
	AcceptUserId        int               `json:"acceptUserId" gorm:"size:48;"`         // 接收者用户id
	AllotCompanyId      int               `json:"allotCompanyId" gorm:"size:48;"`       // 调拨者所属公司id
	AcceptCompanyId     int               `json:"acceptCompanyId" gorm:"size:48;"`      // 接收者所属公司id
	InnerCodeList       model2.StringList `json:"innerCodeList" gorm:"type:json"`       // 单位内编码列表 调拨人发的气瓶列表
	AcceptInnerCodeList model2.StringList `json:"acceptInnerCodeList" gorm:"type:json"` // 单位内编码列表 接收人接收的气瓶列表
	Status              int               `json:"status" gorm:"size:4"`                 // 1-调拨中 2-调拨完成 3-取消调拨 4-超时取消
	AllotType           int               `json:"allotType" gorm:"size:4"`              // 调拨类型 1-扫码调拨 2-一键调拨
	AllotUser           SysUserOmit       `json:"allotUser"  gorm:"foreignkey:AllotUserId;references:Id"`
	AcceptUser          SysUserOmit       `json:"acceptUser"  gorm:"foreignkey:AcceptUserId;references:Id"`
	AllotCompany        SysDeptOmit       `json:"allotCompany"  gorm:"foreignkey:AllotCompanyId;references:Id"`
	AcceptCompany       SysDeptOmit       `json:"acceptCompany" gorm:"->;foreignkey:AcceptCompanyId;references:Id"`

	model2.ControlBy
	model2.ModelTime
	model2.DeptBy
}

func (GasCylinderAllot) TableName() string {
	return "gas_cylinder_allot"
}
