package model

import (
	"database/sql/driver"
	"encoding/json"
	model2 "gas-cylinder-api/common/model"
)

var (
	OrderStateOrder               = 1 // 已下单
	OrderStateDelivery            = 2 // 已派单
	OrderStateArrive              = 3 // 已送达
	OrderStateCancel              = 4 // 已取消
	OrderStateInDelivery          = 5 // 配送中
	OrderStateInDeliveryInspected = 6 // 配送中-已检查

	OrderStateMap = map[int]string{
		OrderStateOrder:               "已下单",
		OrderStateDelivery:            "已派单",
		OrderStateArrive:              "已送达",
		OrderStateCancel:              "已取消",
		OrderStateInDelivery:          "配送中",
		OrderStateInDeliveryInspected: "配送中(已检查)",
	}
)

// 省平台运输企业
type OrderInnerCode struct {
	InnerCode string `json:"innerCode" gorm:"size:48;"` // 单位内编码
	State     int    `json:"state" gorm:"size:10;" `    // 状态 1-正常 2-已取消
}
type OrderInnerCodeList []OrderInnerCode

// 商品管理
type Order struct {
	model2.Model
	OrderId            string             `json:"orderId"  gorm:"size:48"` // 订单id
	CustomerId         string             `json:"customerId"  gorm:"size:48"`
	Address            string             `json:"address" gorm:"size:128"`      // 客户地址
	Phone              string             `json:"phone" gorm:"size:128"`        // 客户电话
	StoreId            int                `json:"storeId"`                      // 配送门店ID
	UserId             int                `json:"userId"`                       // 配送人员ID
	GoodsId            int                `json:"goodsId"`                      // 商品ID
	SpecId             int                `json:"specId"`                       // 规格ID
	Quantity           int                `json:"quantity" gorm:"size:12"`      // 数量
	Source             int                `json:"source" gorm:"size:12"`        // 来源 1-坐席下单 2-小程序
	State              int                `json:"state" gorm:"size:12"`         // 状态 1-已下单 2-已派单-未配送 3-已送达 4-已取消 5-配送中 6-配送中-已检查
	Remark             string             `json:"remark" gorm:"size:1024"`      // 备注
	OrderTime          model2.Time        `json:"orderTime" gorm:"size:128"`    // 下单时间
	DeliveryTime       model2.Time        `json:"deliveryTime" gorm:"size:128"` // 配送时间
	ArriveTime         model2.Time        `json:"arriveTime" gorm:"size:128"`   // 送达时间
	CancelTime         model2.Time        `json:"cancelTime" gorm:"size:128"`   // 取消时间
	OrderInnerCodeList OrderInnerCodeList `json:"orderInnerCodeList" gorm:"type:json"`

	Customer Customer        `json:"customer" gorm:"->"`
	Store    SysDeptOmit     `json:"store" gorm:"->"`
	User     SysUserOmit     `json:"user" gorm:"->"`
	Goods    Goods           `json:"goods" gorm:"->"`
	Spec     GasCylinderSpec `json:"spec" gorm:"->"`
	Dept     SysDeptOmit     `json:"dept" gorm:"->"`
	model2.ControlBy
	model2.ModelTime
	model2.DeptBy
}

func (Order) TableName() string {
	return "order"
}

func (e OrderInnerCodeList) Value() (driver.Value, error) {
	d, err := json.Marshal(e)
	return string(d), err
}

func (e *OrderInnerCodeList) Scan(src interface{}) error {
	return json.Unmarshal(src.([]byte), e)
}
