package service

import (
	"errors"
	"gas-cylinder-api/app/admin/model"
	"gas-cylinder-api/app/admin/service/dto"
	"gas-cylinder-api/common/actions"
	cDto "gas-cylinder-api/common/dto"
	"gas-cylinder-api/common/global"
	"gogs.baozhida.cn/zoie/OAuth-core/service"
	"gorm.io/gorm"
)

type DispatchCost struct {
	service.Service
}

// GetPage 获取DispatchCost列表
func (e *DispatchCost) GetPage(c *dto.DispatchCostGetPageReq, list *[]model.DispatchCost, count *int64, p *actions.DataPermission) error {
	var err error
	var data model.DispatchCost

	err = e.Orm.Model(&data).
		Scopes(
			cDto.MakeCondition(c.GetNeedSearch()),
			cDto.Paginate(c.GetPageSize(), c.GetPageIndex()),
			actions.Permission(data.TableName(), p),
		).
		Find(list).Limit(-1).Offset(-1).
		Count(count).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		return global.GetFailedErr
	}
	return nil
}

// Get 获取DispatchCost对象
func (e *DispatchCost) Get(d *dto.DispatchCostGetReq, carInfoModel *model.DispatchCost, p *actions.DataPermission) error {
	err := e.Orm.
		Scopes(actions.Permission(carInfoModel.TableName(), p)).
		First(carInfoModel, d.GetId()).Error

	if err != nil {
		e.Log.Errorf("db error: %s", err)
		if errors.Is(err, gorm.ErrRecordNotFound) {
			return global.GetNotFoundOrNoPermissionErr
		}
		return global.GetFailedErr
	}

	return nil
}

// Insert 创建DispatchCost对象
func (e *DispatchCost) Insert(c *dto.DispatchCostInsertReq) error {
	var err error
	var data model.DispatchCost

	tx := e.Orm.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	// 添加角色
	c.Generate(&data)
	err = tx.Create(&data).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		return global.CreateFailedErr
	}
	c.Id = data.Id
	return nil

}

// Update 修改DispatchCost对象
func (e *DispatchCost) Update(c *dto.DispatchCostUpdateReq, p *actions.DataPermission) error {
	var err error

	tx := e.Orm.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	var carInfoModel = model.DispatchCost{}
	// 查询角色是否存在
	err = e.Orm.Scopes(actions.Permission(carInfoModel.TableName(), p)).
		First(&carInfoModel, c.GetId()).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		if errors.Is(err, gorm.ErrRecordNotFound) {
			return global.UpdateNotFoundOrNoPermissionErr
		}
		return global.UpdateFailedErr
	}

	c.Generate(&carInfoModel)
	err = tx.Save(&carInfoModel).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		return global.UpdateFailedErr
	}

	c.Id = carInfoModel.Id

	return nil
}

// Remove 删除DispatchCost
func (e *DispatchCost) Remove(c *dto.DispatchCostDeleteReq, p *actions.DataPermission) error {
	var err error

	tx := e.Orm.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	var carInfoModel model.DispatchCost

	// 查询角色是否存在
	err = e.Orm.Scopes(actions.Permission(carInfoModel.TableName(), p)).
		First(&carInfoModel, c.GetId()).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		if errors.Is(err, gorm.ErrRecordNotFound) {
			return global.DeleteNotFoundOrNoPermissionErr
		}
		return global.DeleteFailedErr
	}

	db := tx.Delete(&carInfoModel)

	if err = db.Error; err != nil {
		e.Log.Errorf("db error: %s", err)
		return global.DeleteFailedErr
	}
	if db.RowsAffected == 0 {
		return global.DeleteNotFoundOrNoPermissionErr
	}

	return nil
}
