package dto

import (
	"gas-cylinder-api/app/admin/model"
	"gas-cylinder-api/common/dto"
	common "gas-cylinder-api/common/model"
)

type GasCylinderGetPageReq struct {
	dto.Pagination `search:"-"`
	InnerCode      string `form:"innerCode" search:"type:contains;column:inner_code;table:gas_cylinder"` // 商品名称
	GasCylinderOrder
}
type GasCylinderOrder struct {
	CreatedAtOrder string `search:"type:order;column:created_at;table:gas_cylinder" form:"createdAtOrder" default:"desc"`
}

func (m *GasCylinderGetPageReq) GetNeedSearch() interface{} {
	return *m
}

type GasCylinderGetReq struct {
	InnerCode string `uri:"inner_code"`
}

type GasCylinderGetByUidReq struct {
	ChipUid string `uri:"chipUid"`
}

func (s *GasCylinderGetByUidReq) GetChipUid() interface{} {
	return s.ChipUid
}

type GasCylinderMockReq struct {
	DeptId int `json:"deptId"`
}

type GasCylinderInsertReq struct {
	Id                    int    `json:"id" comment:"编码" swaggerignore:"true"`     // 编码
	InnerCode             string `json:"inner_code" vd:"len($)>0;msg:'单位内编码不能为空'"` // 1单位内编号
	Uid                   string `json:"uid"`                                      // 高频编码 暂时无法获取 同单位内编号
	StationName           string `json:"station_name"`                             // 上次充装气站
	FillTime              string `json:"fill_time"`                                // 上次充装时间
	RegisterSuperviseName string `json:"register_supervise_name"`                  // 使用登记审批单位
	RegisterTime          string `json:"register_time"`                            // 使用登记日期
	ProVariety            string `json:"pro_variety"`                              // 1设备品种
	EnterpriseName        string `json:"enterprise_name"`                          // 产权单位
	ProName               string `json:"pro_name"`                                 // 1产品名称
	ProNo                 string `json:"pro_no"`                                   // 气瓶生产编号 (出厂)编号
	FillMedia             string `json:"fill_media"`                               // 1充装介质：0液化石油气，1二甲醚，2氧气，3二氧化碳，4溶解乙炔
	MakeUnit              string `json:"make_unit"`                                // 1制造单位
	MakeTime              string `json:"make_time"`                                // 1生产日期
	WorkPressure          string `json:"work_pressure"`                            // 1公称工作压口(MPa)
	Volume                string `json:"volume"`                                   // 1容积(L)
	CheckTime             string `json:"check_time"`                               // 1最近一次检验日期(新瓶该值填写出厂日期)
	NextCheckTime         string `json:"next_check_time"`                          // 1下次检验日期(液化石油气瓶顺延4年气瓶下一次需要送检验站检验的日期)
	ProUuid               string `json:"pro_uuid"`                                 // 1产品唯一性编码
	StoreName             string `json:"store_name"`                               // 所属二级配送站
	CirOwnerName          string `json:"cir_owner_name"`                           // 当前流转归属于
	ChangeEvent           string `json:"change_event"`
	Memo                  string `json:"memo"`
	AliasName             string `json:"alias_name"`
	Status                string `json:"status"`
	common.ControlBy      `swaggerignore:"true"`
	common.DeptBy         `swaggerignore:"true"`
}

func (s *GasCylinderInsertReq) Generate(m *model.GasCylinder) {
	if s.Id != 0 {
		m.Id = s.Id
	}
	m.InnerCode = s.InnerCode
	m.Uid = s.Uid
	m.StationName = s.StationName
	m.FillTime = s.FillTime
	m.RegisterSuperviseName = s.RegisterSuperviseName
	m.RegisterTime = s.RegisterTime
	m.ProVariety = s.ProVariety
	m.EnterpriseName = s.EnterpriseName
	m.ProName = s.ProName
	m.ProNo = s.ProNo
	m.FillMedia = s.FillMedia
	m.MakeUnit = s.MakeUnit
	m.MakeTime = s.MakeTime
	m.WorkPressure = s.WorkPressure
	m.Volume = s.Volume
	m.CheckTime = s.CheckTime
	m.NextCheckTime = s.NextCheckTime
	m.ProUuid = s.ProUuid
	m.StoreName = s.StoreName
	m.CirOwnerName = s.CirOwnerName
	m.ChangeEvent = s.ChangeEvent
	m.Memo = s.Memo
	m.AliasName = s.AliasName
	m.Status = s.Status

	if s.ControlBy.UpdateBy != 0 {
		m.UpdateBy = s.UpdateBy
	}
	if s.ControlBy.CreateBy != 0 {
		m.CreateBy = s.CreateBy
	}
	if s.DeptBy.DeptId != 0 && m.DeptId == 0 {
		m.DeptId = s.DeptId
	}
}
func (s *GasCylinderInsertReq) GetId() interface{} {
	return s.Id
}

type GasCylinderUpdateReq struct {
	Id                    int    `json:"id" comment:"编码"`                          // 编码
	InnerCode             string `json:"inner_code" vd:"len($)>0;msg:'单位内编码不能为空'"` // 1单位内编号
	Uid                   string `json:"uid"`                                      // 高频编码 暂时无法获取 同单位内编号
	StationName           string `json:"station_name"`                             // 上次充装气站
	FillTime              string `json:"fill_time"`                                // 上次充装时间
	RegisterSuperviseName string `json:"register_supervise_name"`                  // 使用登记审批单位
	RegisterTime          string `json:"register_time"`                            // 使用登记日期
	ProVariety            string `json:"pro_variety"`                              // 1设备品种
	EnterpriseName        string `json:"enterprise_name"`                          // 产权单位
	ProName               string `json:"pro_name"`                                 // 1产品名称
	ProNo                 string `json:"pro_no"`                                   // 气瓶生产编号 (出厂)编号
	FillMedia             string `json:"fill_media"`                               // 1充装介质：0液化石油气，1二甲醚，2氧气，3二氧化碳，4溶解乙炔
	MakeUnit              string `json:"make_unit"`                                // 1制造单位
	MakeTime              string `json:"make_time"`                                // 1生产日期
	WorkPressure          string `json:"work_pressure"`                            // 1公称工作压口(MPa)
	Volume                string `json:"volume"`                                   // 1容积(L)
	CheckTime             string `json:"check_time"`                               // 1最近一次检验日期(新瓶该值填写出厂日期)
	NextCheckTime         string `json:"next_check_time"`                          // 1下次检验日期(液化石油气瓶顺延4年气瓶下一次需要送检验站检验的日期)
	ProUuid               string `json:"pro_uuid"`                                 // 1产品唯一性编码
	StoreName             string `json:"store_name"`                               // 所属二级配送站
	CirOwnerName          string `json:"cir_owner_name"`                           // 当前流转归属于
	ChangeEvent           string `json:"change_event"`
	Memo                  string `json:"memo"`
	AliasName             string `json:"alias_name"`
	Status                string `json:"status"`
	common.ControlBy      `swaggerignore:"true"`
	common.DeptBy         `swaggerignore:"true"`
}

func (s *GasCylinderUpdateReq) Generate(m *model.GasCylinder) {
	if s.Id != 0 {
		m.Id = s.Id
	}
	m.InnerCode = s.InnerCode
	m.Uid = s.Uid
	m.StationName = s.StationName
	m.FillTime = s.FillTime
	m.RegisterSuperviseName = s.RegisterSuperviseName
	m.RegisterTime = s.RegisterTime
	m.ProVariety = s.ProVariety
	m.EnterpriseName = s.EnterpriseName
	m.ProName = s.ProName
	m.ProNo = s.ProNo
	m.FillMedia = s.FillMedia
	m.MakeUnit = s.MakeUnit
	m.MakeTime = s.MakeTime
	m.WorkPressure = s.WorkPressure
	m.Volume = s.Volume
	m.CheckTime = s.CheckTime
	m.NextCheckTime = s.NextCheckTime
	m.ProUuid = s.ProUuid
	m.StoreName = s.StoreName
	m.CirOwnerName = s.CirOwnerName
	m.ChangeEvent = s.ChangeEvent
	m.Memo = s.Memo
	m.AliasName = s.AliasName
	m.Status = s.Status
	if s.ControlBy.UpdateBy != 0 {
		m.UpdateBy = s.UpdateBy
	}
	if s.ControlBy.CreateBy != 0 {
		m.CreateBy = s.CreateBy
	}
	if s.DeptBy.DeptId != 0 {
		m.DeptId = s.DeptId
	}
}
func (s *GasCylinderUpdateReq) GetId() interface{} {
	return s.Id
}

type GasCylinderDeleteReq struct {
	Id               int `json:"id" vd:"$>0;msg:'id不能为空'"`
	common.ControlBy `swaggerignore:"true"`
}

func (s *GasCylinderDeleteReq) GetId() interface{} {
	return s.Id
}
