package dto

import (
	"gas-cylinder-api/app/admin/model"
	common "gas-cylinder-api/common/model"
	"time"
)

// SysDeptGetPageReq 列表或者搜索使用结构体
type StoreGetPageReq struct {
	Name   string `form:"name" search:"type:contains;column:name;table:sys_dept" example:"部门名称"`    //销售门店名称
	DeptId int    `form:"deptId" search:"-" swaggerignore:"true"`                                   //销售门店名称
	Type   int    `form:"type" search:"type:exact;column:type;table:sys_dept" swaggerignore:"true"` //公司类型
	StoreOrder
}

type StoreOrder struct {
	SortOrder string `search:"type:order;column:sort;table:sys_dept" form:"sort" default:"asc"` //排序 ASC 升序 DESC 降序
}

func (m *StoreGetPageReq) GetNeedSearch() interface{} {
	return *m
}

type StoreInsertReq struct {
	Id               int             `json:"id" swaggerignore:"true"`
	ParentId         int             `json:"parentId" example:"0" vd:"?"`            //上级
	Name             string          `json:"name" example:"名称" swaggerignore:"true"` //名称
	Sort             int             `json:"sort" swaggerignore:"true"`              //排序
	Status           int             `json:"status"  swaggerignore:"true"`           //状态 1-停用 2-正常
	Path             string          `swaggerignore:"true"`                          //路径
	UploadTime       time.Time       `json:"uploadTime" swaggerignore:"true"`        // 省平台上传时间
	Type             int             `json:"type" swaggerignore:"true"`              // 1-销售门店 2-运输企业
	ProvStore        model.ProvStore `json:"provStore"`                              // 销售门店
	StoreCode        string          `json:"storeCode"  swaggerignore:"true"`        // 运输企业在省中心唯一编码
	common.ControlBy `swaggerignore:"true"`
}

func (s *StoreInsertReq) Generate(model *model.SysDept) {
	if s.Id != 0 {
		model.Id = s.Id
	}
	model.Name = s.ProvStore.Name
	model.ParentId = s.ParentId
	model.Sort = 0
	model.Status = 2
	model.Type = 1
	model.ProvStore = s.ProvStore
}

// GetId 获取数据对应的ID
func (s *StoreInsertReq) GetId() interface{} {
	return s.Id
}

type StoreUpdateReq struct {
	Id               int             `json:"id" comment:"编码"`                        // 编码
	Name             string          `json:"name" example:"名称" swaggerignore:"true"` //名称
	Status           int             `json:"status" swaggerignore:"true"`            //状态 1-停用 2-正常
	Sort             int             `json:"sort" swaggerignore:"true"`              //排序
	Path             string          `swaggerignore:"true"`                          //路径
	UploadTime       time.Time       `json:"uploadTime" swaggerignore:"true"`        // 省平台上传时间
	ProvStore        model.ProvStore `json:"provStore"`                              // 销售门店
	common.ControlBy `swaggerignore:"true"`
}

// Generate 结构体数据转化 从 SysDeptControl 至 SysDept 对应的模型
func (s *StoreUpdateReq) Generate(model *model.SysDept) {
	if s.Id != 0 {
		model.Id = s.Id
	}
	model.Name = s.ProvStore.Name
	model.Sort = 0
	model.Status = 2
	model.ProvStore = s.ProvStore
}

// GetId 获取数据对应的ID
func (s *StoreUpdateReq) GetId() interface{} {
	return s.Id
}

type StoreGetReq struct {
	Id int `uri:"id"`
}

func (s *StoreGetReq) GetId() interface{} {
	return s.Id
}

type StoreDeleteReq struct {
	Id int `json:"id"`
}

func (s *StoreDeleteReq) GetId() interface{} {
	return s.Id
}

type StoreEnterReq struct {
	Id int `json:"id"`
}

func (s *StoreEnterReq) GetId() interface{} {
	return s.Id
}

// SysDeptGetPageReq 列表或者搜索使用结构体
type AppletStoreGetPageReq struct {
	Name     string `form:"name" search:"type:contains;column:name;table:sys_dept" example:"部门名称"`    //销售门店名称
	District string `form:"district" search:"-" example:"520100"`                                     //所在地市
	City     string `form:"city" search:"-" example:"520115"`                                         //所在区县
	Type     int    `form:"type" search:"type:exact;column:type;table:sys_dept" swaggerignore:"true"` //公司类型
	StoreOrder
}

func (m *AppletStoreGetPageReq) GetNeedSearch() interface{} {
	return *m
}
