package dto

import (
	"gas-cylinder-api/app/admin/model"
	dto2 "gas-cylinder-api/common/dto"
	model2 "gas-cylinder-api/common/model"
)

type SysUserGetPageReq struct {
	dto2.Pagination `search:"-"`
	Username        string `form:"username" search:"type:contains;column:username;table:sys_user" comment:"用户名"`
	Name            string `form:"name" search:"type:contains;column:nick_name;table:sys_user" comment:"昵称"`
	Uuid            string `form:"uuid" search:"type:contains;column:uuid;table:sys_user" comment:"昵称"`
	RoleId          int    `form:"roleId" search:"type:exact;column:role_id;table:sys_user" comment:"角色ID"`
	DeptId          int    `form:"deptId" search:"type:exact;column:dept_id;table:sys_user" comment:"部门ID"`
	Status          string `form:"status" search:"type:exact;column:status;table:sys_user" comment:"状态"`
	UserType        int    `form:"userType" search:"-"`
	SysUserOrder
}
type SysUserOrder struct {
	//UserIdOrder    string `search:"type:order;column:id;table:sys_user" form:"userIdOrder"`
	//UsernameOrder  string `search:"type:order;column:username;table:sys_user" form:"usernameOrder"`
	//StatusOrder    string `search:"type:order;column:status;table:sys_user" form:"statusOrder"`
	CreatedAtOrder string `search:"type:order;column:created_at;table:sys_user" form:"createdAtOrder" default:"desc"`
}

func (m *SysUserGetPageReq) GetNeedSearch() interface{} {
	return *m
}

type SysUserGetDeliveryPageReq struct {
	dto2.Pagination `search:"-"`
	Name            string `form:"name" search:"type:contains;column:nick_name;table:sys_user" comment:"昵称"`
	StoreId         string `form:"storeId" search:"type:exact;column:dept_id;table:sys_user" comment:"门店id"`
}

func (m *SysUserGetDeliveryPageReq) GetNeedSearch() interface{} {
	return *m
}

type SysUserGetCountReq struct {
	RoleIds []int `form:"roleId" search:"type:in;column:role_id;table:sys_user" comment:"角色ID"`
	DeptIds []int `form:"deptId" search:"type:in;column:dept_id;table:sys_user" comment:"部门ID"`
	PostIds []int `form:"postId" search:"type:in;column:post_id;table:sys_user" comment:"岗位ID"`
}

func (m *SysUserGetCountReq) GetNeedSearch() interface{} {
	return *m
}

type ResetSysUserPwdReq struct {
	Id               int    `json:"id" example:"1" vd:"$>0"`                 // 用户ID
	Password         string `json:"password" example:"123456" vd:"len($)>0"` // 密码
	model2.ControlBy `swaggerignore:"true"`
}

func (s *ResetSysUserPwdReq) GetId() interface{} {
	return s.Id
}

func (s *ResetSysUserPwdReq) Generate(userModel *model.SysUser) {
	if s.Id != 0 {
		userModel.Id = s.Id
	}
	userModel.Password = s.Password
	if s.ControlBy.UpdateBy != 0 {
		userModel.UpdateBy = s.UpdateBy
	}
	if s.ControlBy.CreateBy != 0 {
		userModel.CreateBy = s.CreateBy
	}
}

type UpdateSysUserStatusReq struct {
	Id               int    `json:"id" example:"1" vd:"$>0"`          // 用户ID
	Status           string `json:"status" example:"2" vd:"len($)>0"` // 状态 1-停用 2-正常
	model2.ControlBy `swaggerignore:"true"`
}

func (s *UpdateSysUserStatusReq) GetId() interface{} {
	return s.Id
}

func (s *UpdateSysUserStatusReq) Generate(userModel *model.SysUser) {
	if s.Id != 0 {
		userModel.Id = s.Id
	}
	userModel.Status = s.Status
	if s.ControlBy.UpdateBy != 0 {
		userModel.UpdateBy = s.UpdateBy
	}
	if s.ControlBy.CreateBy != 0 {
		userModel.CreateBy = s.CreateBy
	}
}

type SysUserInsertReq struct {
	Id                           int                                `json:"id" swaggerignore:"true" comment:"用户ID"`                    // 用户ID
	Username                     string                             `json:"username" example:"username" vd:"@:len($)>0;msg:'用户名不能为空'"` // 用户名
	Password                     string                             `json:"password" example:"123456" vd:"@:len($)>5;msg:'密码格式不正确'"`   // 密码
	Name                         string                             `json:"name" swaggerignore:"true"`                                 // 姓名
	Phone                        string                             `json:"phone" swaggerignore:"true"`                                // 手机号
	RoleId                       int                                `json:"roleId" example:"1"`                                        // 角色id
	DeptId                       int                                `json:"deptId" example:"1"  swaggerignore:"true"`                  // 机构id
	Status                       string                             `json:"status" example:"2" swaggerignore:"true"`                   // 状态
	ProvUser                     model.ProvUser                     `json:"provUser"`                                                  // 省平台用户信息
	ProvStoreUserBindCertificate model.ProvStoreUserBindCertificate `json:"provStoreUserBindCertificate"`                              // 送气人员绑定资质信息《燃气从业资格证》
	ProvTruckUserBindCertificate model.ProvTruckUserBindCertificate `json:"provTruckUserBindCertificate"`                              // 货车司机绑定《道路运输从业人员从业资格证》信息
	ProvUserId                   string                             `json:"provUserId"  swaggerignore:"true"`                          // 省平台用户id
	model2.ControlBy             `swaggerignore:"true"`
}

func (s *SysUserInsertReq) Generate(userModel *model.SysUser) {
	if s.Id != 0 {
		userModel.Id = s.Id
	}
	userModel.Username = s.Username
	userModel.Password = s.Password
	userModel.NickName = s.ProvUser.Name
	userModel.Phone = s.ProvUser.Phone
	userModel.DeptId = s.DeptId
	userModel.RoleId = s.RoleId
	userModel.Status = "2"
	userModel.ProvUser = s.ProvUser
	// 门店人员-送气员
	if s.ProvUser.UserType == 3 && s.ProvUser.Isorders == 0 {
		userModel.ProvStoreUserBindCertificate = s.ProvStoreUserBindCertificate
		userModel.ProvStoreUserBindCertificate.UserId = s.ProvUser.UserId
	}
	// 货车司机
	if s.ProvUser.UserType == 4 {
		userModel.ProvTruckUserBindCertificate = s.ProvTruckUserBindCertificate
		userModel.ProvTruckUserBindCertificate.UserId = s.ProvUser.UserId
	}
	userModel.ProvUserId = s.ProvUser.UserId
	if s.ControlBy.UpdateBy != 0 {
		userModel.UpdateBy = s.UpdateBy
	}
	if s.ControlBy.CreateBy != 0 {
		userModel.CreateBy = s.CreateBy
	}
}

func (s *SysUserInsertReq) GetId() interface{} {
	return s.Id
}

type SysUserUpdateReq struct {
	Id                           int                                `json:"id" swaggerignore:"true" comment:"用户ID"`   // 用户ID
	Name                         string                             `json:"name" swaggerignore:"true"`                // 姓名
	Phone                        string                             `json:"phone" swaggerignore:"true"`               // 手机号
	RoleId                       int                                `json:"roleId" example:"1"`                       // 角色id
	DeptId                       int                                `json:"deptId" example:"1"  swaggerignore:"true"` // 机构id
	Status                       string                             `json:"status" example:"2" swaggerignore:"true"`  // 状态
	ProvUser                     model.ProvUser                     `json:"provUser"`                                 // 省平台用户信息
	ProvStoreUserBindCertificate model.ProvStoreUserBindCertificate `json:"provStoreUserBindCertificate"`             // 送气人员绑定资质信息《燃气从业资格证》
	ProvTruckUserBindCertificate model.ProvTruckUserBindCertificate `json:"provTruckUserBindCertificate"`             // 货车司机绑定《道路运输从业人员从业资格证》信息
	ProvUserId                   string                             `json:"provUserId"  swaggerignore:"true"`         // 省平台用户id
	model2.ControlBy             `swaggerignore:"true"`
}

func (s *SysUserUpdateReq) Generate(userModel *model.SysUser) {
	if s.Id != 0 {
		userModel.Id = s.Id
	}
	userModel.NickName = s.ProvUser.Name
	userModel.Phone = s.ProvUser.Phone
	userModel.DeptId = s.DeptId
	userModel.RoleId = s.RoleId
	userModel.Status = "2"
	if len(s.ProvUser.Name) > 0 {
		userModel.ProvUser.Name = s.ProvUser.Name
	}
	if len(s.ProvUser.IdCard) > 0 {
		userModel.ProvUser.IdCard = s.ProvUser.IdCard
	}
	if len(s.ProvUser.No) > 0 {
		userModel.ProvUser.No = s.ProvUser.No
	}
	if len(s.ProvUser.Phone) > 0 {
		userModel.ProvUser.Phone = s.ProvUser.Phone
	}
	if s.ProvUser.UserType > 0 {
		userModel.ProvUser.UserType = s.ProvUser.UserType
	}
	if len(s.ProvUser.Description) > 0 {
		userModel.ProvUser.Description = s.ProvUser.Description
	}
	if len(s.ProvUser.HireStatus) > 0 {
		userModel.ProvUser.HireStatus = s.ProvUser.HireStatus
	}
	if len(s.ProvUser.HireTime) > 0 {
		userModel.ProvUser.HireTime = s.ProvUser.HireTime
	}
	if len(s.ProvUser.Education) > 0 {
		userModel.ProvUser.Education = s.ProvUser.Education
	}
	if len(s.ProvUser.JobCategory) > 0 {
		userModel.ProvUser.JobCategory = s.ProvUser.JobCategory
	}
	if len(s.ProvUser.PersonQual) > 0 {
		userModel.ProvUser.PersonQual = s.ProvUser.PersonQual
	}
	if s.ProvUser.Isorders >= 0 {
		userModel.ProvUser.Isorders = s.ProvUser.Isorders
	}

	// 门店人员-送气员
	if userModel.ProvUser.UserType == 3 && userModel.ProvUser.Isorders == 0 {
		storeUser := s.ProvStoreUserBindCertificate
		userModel.ProvStoreUserBindCertificate.UserId = userModel.ProvUser.UserId

		if len(storeUser.CertificateNo) > 0 {
			userModel.ProvStoreUserBindCertificate.CertificateNo = storeUser.CertificateNo
		}
		if storeUser.Type > 0 {
			userModel.ProvStoreUserBindCertificate.Type = storeUser.Type
		}
		if len(storeUser.IssueAuthority) > 0 {
			userModel.ProvStoreUserBindCertificate.IssueAuthority = storeUser.IssueAuthority
		}
		if len(storeUser.IssueTime) > 0 {
			userModel.ProvStoreUserBindCertificate.IssueTime = storeUser.IssueTime
		}
		if len(storeUser.ImgUrl) > 0 {
			userModel.ProvStoreUserBindCertificate.ImgUrl = storeUser.ImgUrl
		}
		if len(storeUser.Remarks) > 0 {
			userModel.ProvStoreUserBindCertificate.Remarks = storeUser.Remarks
		}

	}
	// 货车司机
	if userModel.ProvUser.UserType == 4 {
		truckUser := s.ProvTruckUserBindCertificate
		userModel.ProvTruckUserBindCertificate.UserId = userModel.ProvUser.UserId

		if len(truckUser.CertificateNo) > 0 {
			userModel.ProvTruckUserBindCertificate.CertificateNo = truckUser.CertificateNo
		}
		if truckUser.Type > 0 {
			userModel.ProvTruckUserBindCertificate.Type = truckUser.Type
		}
		if len(truckUser.IssueAuthority) > 0 {
			userModel.ProvTruckUserBindCertificate.IssueAuthority = truckUser.IssueAuthority
		}
		if len(truckUser.IssueTime) > 0 {
			userModel.ProvTruckUserBindCertificate.IssueTime = truckUser.IssueTime
		}
		if len(truckUser.FirstIssueTime) > 0 {
			userModel.ProvTruckUserBindCertificate.FirstIssueTime = truckUser.FirstIssueTime
		}
		if len(truckUser.ExpireTime) > 0 {
			userModel.ProvTruckUserBindCertificate.ExpireTime = truckUser.ExpireTime
		}
		if len(truckUser.ImgUrl) > 0 {
			userModel.ProvTruckUserBindCertificate.ImgUrl = truckUser.ImgUrl
		}
		if len(truckUser.Remarks) > 0 {
			userModel.ProvTruckUserBindCertificate.Remarks = truckUser.Remarks
		}
	}
	if s.ControlBy.UpdateBy != 0 {
		userModel.UpdateBy = s.UpdateBy
	}
	if s.ControlBy.CreateBy != 0 {
		userModel.CreateBy = s.CreateBy
	}
}

func (s *SysUserUpdateReq) GetId() interface{} {
	return s.Id
}

type SysUserGetReq struct {
	Id int `uri:"id"`
}

func (s *SysUserGetReq) GetId() interface{} {
	return s.Id
}

type SysUserDeleteReq struct {
	Id               int `json:"id"`
	model2.ControlBy `swaggerignore:"true"`
}

func (s *SysUserDeleteReq) GetId() interface{} {
	return s.Id
}

type SysUserById struct {
	dto2.ObjectById
	model2.ControlBy `swaggerignore:"true"`
}

func (s *SysUserById) GetIds() interface{} {
	return s.Ids
}

func (s *SysUserById) GetId() interface{} {
	if len(s.Ids) > 0 {
		s.Ids = append(s.Ids, s.Id)
		return s.Ids
	}
	return s.Id
}

func (s *SysUserById) GenerateM() (model2.ActiveRecord, error) {
	return &model.SysUser{}, nil
}

// PassWord 密码
type PassWord struct {
	NewPassword string `json:"newPassword" example:"123456" vd:"len($)>0"`   // 新密码
	OldPassword string `json:"oldPassword" example:"12345678" vd:"len($)>0"` // 旧密码
}

type SysUserGetSMSVerifyCodeReq struct {
	Phone string `form:"phone" example:"13912345678"` //手机号
}
type GetNewestTokenReq struct {
	UserId int64 `uri:"userId" example:"1"` //手机号
}

type SysUserGetPageByOptTypeReq struct {
	dto2.Pagination `search:"-"`
	OptType         string `form:"optType" search:"-"` // 气瓶流转步骤
	Name    string `form:"name" search:"type:contains;column:nick_name;table:sys_user" comment:"昵称"`
	StoreId string `form:"storeId" search:"type:exact;column:dept_id;table:sys_user" comment:"门店id"`
}

func (m *SysUserGetPageByOptTypeReq) GetNeedSearch() interface{} {
	return *m
}
