package dto

import (
	"gas-cylinder-api/app/admin/model"
	common "gas-cylinder-api/common/model"
	"time"
)

// SysDeptGetPageReq 列表或者搜索使用结构体
type TruckEnterpriseGetPageReq struct {
	Name   string `form:"name" search:"type:contains;column:name;table:sys_dept" example:"名称"`      //名称
	DeptId int    `form:"deptId" search:"-" swaggerignore:"true"`                                   //id
	Type   int    `form:"type" search:"type:exact;column:type;table:sys_dept" swaggerignore:"true"` //公司类型
	TruckEnterpriseOrder
}

type TruckEnterpriseOrder struct {
	SortOrder string `search:"type:order;column:sort;table:sys_dept" form:"sort" default:"asc"` //排序 ASC 升序 DESC 降序
}

func (m *TruckEnterpriseGetPageReq) GetNeedSearch() interface{} {
	return *m
}

type TruckEnterpriseInsertReq struct {
	Id                  int                       `json:"id" swaggerignore:"true"`
	ParentId            int                       `json:"parentId" example:"0" vd:"?"`            // 上级
	Name                string                    `json:"name" example:"名称" swaggerignore:"true"` // 名称
	Sort                int                       `json:"sort" swaggerignore:"true"`              // 排序
	Status              int                       `json:"status"  swaggerignore:"true"`           // 状态 1-停用 2-正常
	Path                string                    `swaggerignore:"true"`                          // 路径
	UploadTime          time.Time                 `json:"uploadTime" swaggerignore:"true"`        // 省平台上传时间
	Type                int                       `json:"type" swaggerignore:"true"`              // 1-销售门店 2-运输企业
	ProvTruckEnterprise model.ProvTruckEnterprise `json:"provTruckEnterprise"`                    // 运输企业
	CmpCode             string                    `json:"cmpCode"  swaggerignore:"true"`          // 运输企业在省中心唯一编码
	common.ControlBy    `swaggerignore:"true"`
}

func (s *TruckEnterpriseInsertReq) Generate(model *model.SysDept) {
	if s.Id != 0 {
		model.Id = s.Id
	}
	model.Name = s.ProvTruckEnterprise.Name
	model.ParentId = s.ParentId
	model.Sort = 0
	model.Status = 2
	model.Type = 2
	model.ProvTruckEnterprise = s.ProvTruckEnterprise
}

// GetId 获取数据对应的ID
func (s *TruckEnterpriseInsertReq) GetId() interface{} {
	return s.Id
}

type TruckEnterpriseUpdateReq struct {
	Id                  int                       `json:"id" comment:"编码"`                        // 编码
	Name                string                    `json:"name" example:"名称" swaggerignore:"true"` // 名称
	Status              int                       `json:"status" swaggerignore:"true"`            // 状态 1-停用 2-正常
	Sort                int                       `json:"sort" swaggerignore:"true"`              // 排序
	Path                string                    `swaggerignore:"true"`                          // 路径
	UploadTime          time.Time                 `json:"uploadTime" swaggerignore:"true"`        // 省平台上传时间
	ProvTruckEnterprise model.ProvTruckEnterprise `json:"provTruckEnterprise"`                    // 运输企业
	common.ControlBy    `swaggerignore:"true"`
}

// Generate 结构体数据转化 从 SysDeptControl 至 SysDept 对应的模型
func (s *TruckEnterpriseUpdateReq) Generate(model *model.SysDept) {
	if s.Id != 0 {
		model.Id = s.Id
	}
	model.Name = s.ProvTruckEnterprise.Name
	model.Sort = 0
	model.Status = 2
	model.ProvTruckEnterprise = s.ProvTruckEnterprise
}

// GetId 获取数据对应的ID
func (s *TruckEnterpriseUpdateReq) GetId() interface{} {
	return s.Id
}

type TruckEnterpriseGetReq struct {
	Id int `uri:"id"`
}

func (s *TruckEnterpriseGetReq) GetId() interface{} {
	return s.Id
}

type TruckEnterpriseDeleteReq struct {
	Id int `json:"id"`
}

func (s *TruckEnterpriseDeleteReq) GetId() interface{} {
	return s.Id
}

type TruckEnterpriseEnterReq struct {
	Id int `json:"id"`
}

func (s *TruckEnterpriseEnterReq) GetId() interface{} {
	return s.Id
}
