package service

import (
	"errors"
	"gas-cylinder-api/app/admin/model"
	"gas-cylinder-api/app/admin/service/dto"
	"gas-cylinder-api/common/actions"
	cDto "gas-cylinder-api/common/dto"
	"gas-cylinder-api/common/global"
	"gogs.baozhida.cn/zoie/OAuth-core/service"
	"gorm.io/gorm"
)

type FillGun struct {
	service.Service
}

// GetPage 获取FillGun列表
func (e *FillGun) GetPage(c *dto.FillGunGetPageReq, list *[]model.FillGun, count *int64, p *actions.DataPermission) error {
	var err error
	var data model.FillGun

	err = e.Orm.Model(&data).
		Scopes(
			cDto.MakeCondition(c.GetNeedSearch()),
			cDto.Paginate(c.GetPageSize(), c.GetPageIndex()),
			actions.Permission(data.TableName(), p),
		).
		Find(list).Limit(-1).Offset(-1).
		Count(count).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		return global.GetFailedErr
	}
	return nil
}

// Get 获取FillGun对象
func (e *FillGun) Get(d *dto.FillGunGetReq, fillGunModel *model.FillGun, p *actions.DataPermission) error {
	err := e.Orm.
		Scopes(actions.Permission(fillGunModel.TableName(), p)).
		First(fillGunModel, d.GetId()).Error

	if err != nil {
		e.Log.Errorf("db error: %s", err)
		if errors.Is(err, gorm.ErrRecordNotFound) {
			return global.GetNotFoundOrNoPermissionErr
		}
		return global.GetFailedErr
	}

	return nil
}
func (e *FillGun) GetByCode(gunCode string, fillGunModel *model.FillGun) error {
	err := e.Orm.
		Where("scan_gun_code = ?", gunCode).
		Preload("Dept").
		First(fillGunModel).Error

	if err != nil {
		e.Log.Errorf("db error: %s", err)
		if errors.Is(err, gorm.ErrRecordNotFound) {
			return global.GetNotFoundOrNoPermissionErr
		}
		return global.GetFailedErr
	}

	return nil
}

// Insert 创建FillGun对象
func (e *FillGun) Insert(c *dto.FillGunInsertReq) error {
	var err error
	var data model.FillGun

	tx := e.Orm.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	// TODO 1.1.1.12新运输增车辆信息

	// 添加角色
	c.Generate(&data)
	err = tx.Create(&data).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		return global.CreateFailedErr
	}
	c.Id = data.Id
	return nil

}

// Update 修改FillGun对象
func (e *FillGun) Update(c *dto.FillGunUpdateReq, p *actions.DataPermission) error {
	var err error

	tx := e.Orm.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	var fillGunModel = model.FillGun{}
	// 查询角色是否存在
	err = e.Orm.Scopes(actions.Permission(fillGunModel.TableName(), p)).
		First(&fillGunModel, c.GetId()).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		if errors.Is(err, gorm.ErrRecordNotFound) {
			return global.UpdateNotFoundOrNoPermissionErr
		}
		return global.UpdateFailedErr
	}

	// TODO 1.1.1.13更新车辆信息

	c.Generate(&fillGunModel)
	err = tx.Save(&fillGunModel).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		return global.UpdateFailedErr
	}

	c.Id = fillGunModel.Id

	return nil
}

// Remove 删除FillGun
func (e *FillGun) Remove(c *dto.FillGunDeleteReq, p *actions.DataPermission) error {
	var err error

	tx := e.Orm.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	var fillGunModel model.FillGun

	// 查询角色是否存在
	err = e.Orm.Scopes(actions.Permission(fillGunModel.TableName(), p)).
		First(&fillGunModel, c.GetId()).Error
	if err != nil {
		e.Log.Errorf("db error: %s", err)
		if errors.Is(err, gorm.ErrRecordNotFound) {
			return global.DeleteNotFoundOrNoPermissionErr
		}
		return global.DeleteFailedErr
	}

	db := tx.Delete(&fillGunModel)

	if err = db.Error; err != nil {
		e.Log.Errorf("db error: %s", err)
		return global.DeleteFailedErr
	}
	if db.RowsAffected == 0 {
		return global.DeleteNotFoundOrNoPermissionErr
	}

	return nil
}
